==> cmsmadesimple-1.6.4.tgz: cms/modules/FileManager/lang/ext/tr_TR.php <==
<?php
$lang['friendlyname'] = 'Dosya Y&ouml;neticisi';
$lang['permission'] = 'Usage of the the File Manager module';
$lang['permissionadvanced'] = 'Advanced usage of the the File Manager module';
$lang['moddescription'] = 'Handling of files and directories in the upload-filesection of cmsms';
$lang['installed'] = 'FileManager version %s installed';
$lang['postinstall'] = 'FileManager module was installed';
$lang['uninstalled'] = 'FileManager module uninstalled';
$lang['really_uninstall'] = 'Are you sure the FileManager module should be uninstalled?';
$lang['upgraded'] = 'FileManager module was upgraded to version %s';
$lang['fileview'] = 'Dosya G&ouml;r&uuml;n&uuml;m&uuml;';
$lang['switchtofileview'] = 'Switch to file view';
$lang['settings'] = 'Ayarlar';
$lang['savesettings'] = 'Ayarları Kaydet';
$lang['filename'] = 'Dosya Adı';
$lang['fileinfo'] = 'Dosya Bilgisi';
$lang['fileowner'] = 'Fileowner';
$lang['fileperms'] = 'İzinler';
$lang['filesize'] = 'Boyut';
$lang['filedate'] = 'Tarih';
$lang['actions'] = 'Eylemler';
$lang['delete'] = 'Sil';
$lang['notwritable'] = 'Yazılamaz';
$lang['filetoobig'] = 'dosyası &ccedil;ok b&uuml;y&uuml;k. Y&uuml;kleme iptal edildi.';
$lang['unknown'] = 'Unknown';
$lang['fileoutsideuploads'] = 'You are not allowed to modify files outside the uploads-dir! (That requires the Advanced File Management permission)';
$lang['writable'] = 'Yazılabilir';
$lang['writeprotected'] = 'Dosya Korumalı';
$lang['bytes'] = 'bytes';
$lang['kb'] = 'kb';
$lang['mb'] = 'mb';
$lang['files'] = 'dosyalar';
$lang['bytesin'] = 'bytes in';
$lang['in'] = 'in';
$lang['file'] = 'dosya';
$lang['fileno'] = 'Dosya no.';
$lang['subdirs'] = 'Alt dizinler';
$lang['subdir'] = 'altdizin';
$lang['and'] = 've';
$lang['confirmsingledelete'] = 'Eminmisiniz?';
$lang['confirmsingledirdelete'] = 'Are you sure this directory should be deleted?';
$lang['dirtreedeletesuccess'] = 'The dir including content was successfully deleted.';
$lang['dirtreedeletefail'] = 'An error occured when deleting this dir. Some of the contents may have been deleted, however.';
$lang['singlefiledeletesuccess'] = 'The file was successfully deleted';
$lang['filedeletesuccess'] = 'was successfully deleted';
$lang['singlefiledeletefail'] = 'An error occurred when trying to delete the file';
$lang['filedeletefail'] = ' was not deleted due to an error';
$lang['singledirdeletesuccess'] = 'The directory  was successfully deleted';
$lang['singledirdeletefail'] = 'An error occurred when trying to delete the directory (is it empty?)';
$lang['deleteselected'] = 'Delete the selected files';
$lang['confirmselected'] = 'Are you sure?';
$lang['confirmdeleteselected'] = 'Are you sure the selected files should be deleted?';
$lang['deleteselectedcancelled'] = 'Deletion of selected files cancelled';
$lang['recursetext'] = 'Recurse into subdirs';
$lang['nofilesselected'] = 'No files selected';
$lang['moveselected'] = 'Move the selected files';
$lang['copyselected'] = 'Copy the selected files';
$lang['selecttargetdir'] = 'Select target dir for move/copy';
$lang['movedto'] = 'moved to';
$lang['copiedto'] = 'copied to';
$lang['couldnotmove'] = 'could not be moved';
$lang['couldnotcopy'] = 'could not copied';
$lang['rename'] = 'Yeniden Adlandır';
$lang['newname'] = 'Yeni Dosya Adı:';
$lang['renamesuccess'] = 'File successfully renamed';
$lang['renamefailure'] = 'Renaming of file failed';
$lang['renamecancelled'] = 'Renaming cancelled';
$lang['owner'] = 'Owner';
$lang['group'] = 'Group';
$lang['others'] = 'Others';
$lang['newpermissions'] = 'New permissions:';
$lang['setpermissions'] = 'Set permissions';
$lang['permissionstyle'] = 'Permission style';
$lang['rwxstyle'] = 'rwx style';
$lang['755style'] = '755 style';
$lang['quickmode'] = 'Quick chmod (like 777)';
$lang['chmod'] = 'Change permissions';
$lang['chmodselected'] = 'Change permissions on selected files';
$lang['chmodsuccess'] = 'File successfully got new permissions';
$lang['chmodfailure'] = 'Changing permissions of file failed';
$lang['chmodcancelled'] = 'Changing of permissions cancelled';
$lang['dirchmodfailmulti'] = 'Changing permissions on the directory failed, some of it&#039;s content may have gotten new permissions, though.';
$lang['dirchmodsuccessmulti'] = 'Changing permissions on the directory and it&#039;s content was successful';
$lang['dirchmodsuccess'] = 'The directory successfully got new permissions';
$lang['dirchmodfailure'] = 'Changing permissions of the directory failed';
$lang['dirnotemptyconfirm'] = 'This dir is not empty. Do you really want to delete it and all content, including subdirs?';
$lang['dirtreedeletecancelled'] = 'Deletion of dir cancelled';
$lang['imsure'] = 'I&#039;m sure';
$lang['cancel'] = 'İptal';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Upload new file(s):';
$lang['unpackafterupload'] = 'Try to unpack file after upload (only tgz and most zip-files)?';
$lang['uploadsuccess'] = 'was uploaded successfully';
$lang['uploadfail'] = 'failed to upload successfully';
$lang['unpacksuccess'] = 'was successfully unpacked';
$lang['unpackfail'] = ' failed with this error: ';
$lang['packfileopenfail'] = 'Could not open the packed file for unpacking (non-supported format?)';
$lang['packfilewritefail'] = 'Could not open the file %s for writing';
$lang['currentpath'] = 'Current path:';
$lang['newdirname'] = 'Create new directory:';
$lang['newdirsuccess'] = 'The directory was created successfully';
$lang['newdirfail'] = 'An error occurred while trying to create the directory';
$lang['invalidnewdir'] = 'Name of new directory cannot contain chars like /, \ and &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s';
$lang['iconsize'] = 'Icon size';
$lang['smallicons'] = 'Small icons';
$lang['largeicons'] = 'Large icons';
$lang['thousanddelimiter'] = 'Thousand delimiter';
$lang['none'] = 'None';
$lang['space'] = 'space';
$lang['showthumbnails'] = 'Show thumbnails';
$lang['showthumbnailshelp'] = 'Enabling this will show thumbnails of image-files if they exist, and will hide the actual thumbnail-file. Disabling will simply show all files.';
$lang['uploadfilesto'] = 'Uploading files to:';
$lang['uploadview'] = 'Dosya Y&uuml;kle';
$lang['uploadboxes'] = 'Number of uploadboxes';
$lang['nothinguploaded'] = 'Nothing uploaded';
$lang['unsupportedarchive'] = 'Unsupported archive format';
$lang['uploadmethod'] = 'Upload method';
$lang['uploaderstandard'] = 'Standard html input-method (allows unpacking)';
$lang['enableadvanced'] = 'Enable advanced mode?';
$lang['advancedhelp'] = 'Lets you gain access to whole cmsms filesystem, not just /uploads/ (if allowed)';
$lang['showhiddenfileshelp'] = 'Only effective with advanced mode on';
$lang['showhiddenfiles'] = 'Gizli Dosyaları G&ouml;ster';
$lang['settingsconfirmsingledelete'] = 'Confirm deletion of a single file?';
$lang['settingssaved'] = 'Ayarlar Kaydedildi';
$lang['help'] = '		<h3>What does this do?</h3>
		<p>This module provides file management functions</p>
		<h3>How do I use it?</h3>
		<p>Select it from the content-menu from in the admin. </p>';
$lang['utma'] = '156861353.896187631.1236676121.1245450321.1245828226.32';
$lang['utmz'] = '156861353.1244804747.30.11.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/search';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.8.2p0.tgz: cms/modules/FileManager/lang/ext/tr_TR.php <==
<?php
$lang['friendlyname'] = 'Dosya Y&ouml;neticisi';
$lang['permission'] = 'Usage of the the File Manager module';
$lang['permissionadvanced'] = 'Advanced usage of the the File Manager module';
$lang['moddescription'] = 'Handling of files and directories in the upload-filesection of cmsms';
$lang['installed'] = 'FileManager version %s installed';
$lang['postinstall'] = 'FileManager module was installed';
$lang['uninstalled'] = 'FileManager module uninstalled';
$lang['really_uninstall'] = 'Are you sure the FileManager module should be uninstalled?';
$lang['upgraded'] = 'FileManager module was upgraded to version %s';
$lang['fileview'] = 'Dosya G&ouml;r&uuml;n&uuml;m&uuml;';
$lang['switchtofileview'] = 'Dosya g&ouml;r&uuml;n&uuml;m&uuml;ne ge&ccedil;';
$lang['settings'] = 'Ayarlar';
$lang['savesettings'] = 'Ayarları Kaydet';
$lang['filename'] = 'Dosya Adı';
$lang['fileinfo'] = 'Dosya Bilgisi';
$lang['fileowner'] = 'Dosya Sahibi';
$lang['fileperms'] = 'İzinler';
$lang['filesize'] = 'Boyut';
$lang['filedate'] = 'Tarih';
$lang['actions'] = 'Eylemler';
$lang['delete'] = 'Sil';
$lang['notwritable'] = 'Yazılamaz';
$lang['filetoobig'] = 'dosyası &ccedil;ok b&uuml;y&uuml;k. Y&uuml;kleme iptal edildi.';
$lang['unknown'] = 'Bilinmeyen';
$lang['fileoutsideuploads'] = 'You are not allowed to modify files outside the uploads-dir! (That requires the Advanced File Management permission)';
$lang['writable'] = 'Yazılabilir';
$lang['writeprotected'] = 'Dosya Korumalı';
$lang['bytes'] = 'bayt';
$lang['kb'] = 'kb';
$lang['mb'] = 'mb';
$lang['files'] = 'dosyalar';
$lang['bytesin'] = 'bytes in';
$lang['in'] = 'in';
$lang['file'] = 'dosya';
$lang['fileno'] = 'Dosya no.';
$lang['subdirs'] = 'Alt dizinler';
$lang['subdir'] = 'altdizin';
$lang['and'] = 've';
$lang['confirmsingledelete'] = 'Eminmisiniz?';
$lang['confirmsingledirdelete'] = 'Klas&ouml;r&uuml; silmek istediğinize emin misiniz?';
$lang['dirtreedeletesuccess'] = 'The dir including content was successfully deleted.';
$lang['dirtreedeletefail'] = 'An error occured when deleting this dir. Some of the contents may have been deleted, however.';
$lang['singlefiledeletesuccess'] = 'Dosya başarıyla silindi';
$lang['filedeletesuccess'] = 'silindi';
$lang['singlefiledeletefail'] = 'An error occurred when trying to delete the file';
$lang['filedeletefail'] = ' was not deleted due to an error';
$lang['singledirdeletesuccess'] = 'The directory  was successfully deleted';
$lang['singledirdeletefail'] = 'An error occurred when trying to delete the directory (is it empty?)';
$lang['deleteselected'] = 'Se&ccedil;ili dosyaları sil';
$lang['confirmselected'] = 'Emin misiniz?';
$lang['confirmdeleteselected'] = 'Se&ccedil;ili dosyaları silmek istediğinize emin misiniz?';
$lang['deleteselectedcancelled'] = 'Se&ccedil;ili dosyaların silinmesinden vazge&ccedil;ildi.';
$lang['recursetext'] = 'Recurse into subdirs';
$lang['nofilesselected'] = 'Dosya se&ccedil;ilmedi';
$lang['moveselected'] = 'Se&ccedil;ili dosyaları taşı';
$lang['copyselected'] = 'Se&ccedil;ili dosyaları kopyala';
$lang['selecttargetdir'] = 'Hedef se&ccedil;imi taşı/kopyala i&ccedil;in';
$lang['movedto'] = 'taşındı';
$lang['copiedto'] = 'kopyalandı';
$lang['couldnotmove'] = 'taşınamadı';
$lang['couldnotcopy'] = 'kopyalanamadı';
$lang['rename'] = 'Yeniden Adlandır';
$lang['newname'] = 'Yeni Dosya Adı:';
$lang['renamesuccess'] = 'Dosya adı değiştirildi';
$lang['renamefailure'] = 'Dosya adı değitirme hatası';
$lang['renamecancelled'] = 'Yeniden adlandırma iptal edildi';
$lang['owner'] = 'Sahip';
$lang['group'] = 'Grup';
$lang['others'] = 'Diğerleri';
$lang['newpermissions'] = 'Yeni İzinler:';
$lang['setpermissions'] = 'İzinleri Belirle';
$lang['permissionstyle'] = 'Permission style';
$lang['rwxstyle'] = 'rwx style';
$lang['755style'] = '755 style';
$lang['quickmode'] = 'Quick chmod (like 777)';
$lang['chmod'] = 'Change permissions';
$lang['chmodselected'] = 'Change permissions on selected files';
$lang['chmodsuccess'] = 'File successfully got new permissions';
$lang['chmodfailure'] = 'Changing permissions of file failed';
$lang['chmodcancelled'] = 'Changing of permissions cancelled';
$lang['dirchmodfailmulti'] = 'Changing permissions on the directory failed, some of it&#039;s content may have gotten new permissions, though.';
$lang['dirchmodsuccessmulti'] = 'Changing permissions on the directory and it&#039;s content was successful';
$lang['dirchmodsuccess'] = 'The directory successfully got new permissions';
$lang['dirchmodfailure'] = 'Changing permissions of the directory failed';
$lang['dirnotemptyconfirm'] = 'This dir is not empty. Do you really want to delete it and all content, including subdirs?';
$lang['dirtreedeletecancelled'] = 'Deletion of dir cancelled';
$lang['imsure'] = 'I&#039;m sure';
$lang['cancel'] = 'İptal';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Yeni dosya(lar) y&uuml;kle:';
$lang['unpackafterupload'] = 'Try to unpack file after upload (only tgz and most zip-files)?';
$lang['uploadsuccess'] = 'y&uuml;klendi';
$lang['uploadfail'] = 'y&uuml;kleme hatası';
$lang['unpacksuccess'] = 'başarıyla a&ccedil;ıldı';
$lang['unpackfail'] = ' failed with this error: ';
$lang['packfileopenfail'] = 'Could not open the packed file for unpacking (non-supported format?)';
$lang['packfilewritefail'] = 'Could not open the file %s for writing';
$lang['containsillegalchars'] = 'Filename contains one or more illegal characters (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['currentpath'] = 'Current path:';
$lang['newdirname'] = 'Yeni klas&ouml;r oluştur:';
$lang['newdirsuccess'] = 'Klas&ouml;r başarıyla oluşturuldu';
$lang['newdirfail'] = 'An error occurred while trying to create the directory';
$lang['invalidnewdir'] = 'Name of new directory cannot contain chars like /, \ and &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s';
$lang['iconsize'] = 'Icon size';
$lang['smallicons'] = 'K&uuml;&ccedil;&uuml;k ikonlar';
$lang['largeicons'] = 'B&uuml;y&uuml;k ikonlar';
$lang['thousanddelimiter'] = 'Binlik ayracı';
$lang['none'] = 'None';
$lang['space'] = 'boşluk';
$lang['showthumbnails'] = 'Show thumbnails';
$lang['showthumbnailshelp'] = 'Enabling this will show thumbnails of image-files if they exist, and will hide the actual thumbnail-file. Disabling will simply show all files.';
$lang['uploadfilesto'] = 'Uploading files to:';
$lang['uploadview'] = 'Dosya Y&uuml;kle';
$lang['uploadboxes'] = 'Number of uploadboxes';
$lang['nothinguploaded'] = 'Nothing uploaded';
$lang['unsupportedarchive'] = 'Unsupported archive format';
$lang['uploadmethod'] = 'Upload method';
$lang['uploaderstandard'] = 'Standard html input-method (allows unpacking)';
$lang['enableadvanced'] = 'Enable advanced mode?';
$lang['advancedhelp'] = 'Lets you gain access to whole cmsms filesystem, not just /uploads/ (if allowed)';
$lang['showhiddenfileshelp'] = 'Only effective with advanced mode on';
$lang['showhiddenfiles'] = 'Gizli Dosyaları G&ouml;ster';
$lang['settingsconfirmsingledelete'] = 'Confirm deletion of a single file?';
$lang['settingssaved'] = 'Ayarlar Kaydedildi';
$lang['help'] = '		<h3>What does this do?</h3>
		<p>This module provides file management functions</p>
		<h3>How do I use it?</h3>
		<p>Select it from the content-menu from in the admin. </p>';
$lang['utma'] = '156861353.1664897565.1272759163.1273489088.1273617025.8';
$lang['utmz'] = '156861353.1273231691.2.2.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms';
$lang['qca'] = 'P0-1960756361-1272759163370';
$lang['utmb'] = '156861353.2.10.1273617025';
$lang['utmc'] = '156861353';
?>
